@@ -47,8 +47,9 @@ def logicle(
         Moore WA and Parks DR. Update for the logicle data scale including operational
         code implementations. Cytometry A., 2012:81A(4):273–277.
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter for the top of the linear scale (e.g. 262144)
     :param m: parameter for the number of decades the true logarithmic scale
         approaches at the high end of the scale
@@ -59,10 +60,16 @@ def logicle(
     """
     data_copy = data.copy()
 
-    # run logicle scale for each channel separately
-    for i in channel_indices:
-        tmp = _logicle(data_copy[:, i].T, t, m, w, a)
-        data_copy.T[i] = tmp
+    if len(data.shape) == 1:
+        data_copy = _logicle(data_copy, t, m, w, a)
+    else:
+        # run logicle scale for each channel separately
+        if channel_indices is None:
+            channel_indices = range(data.shape[1])
+        for i in channel_indices:
+            tmp = _logicle(data_copy[:, i].T, t, m, w, a)
+            data_copy.T[i] = tmp
+
     return data_copy
 
 
@@ -77,8 +84,9 @@ def logicle_inverse(
     """
     Inverse of the Logicle transformation (see `logicle()` documentation for more details)
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter for the top of the linear scale (e.g. 262144)
     :param m: parameter for the number of decades the true logarithmic scale
         approaches at the high end of the scale
@@ -89,10 +97,16 @@ def logicle_inverse(
     """
     data_copy = data.copy()
 
-    # run logicle scale for each channel separately
-    for i in channel_indices:
-        tmp = _logicle_inverse(data_copy[:, i].T, t, m, w, a)
-        data_copy.T[i] = tmp
+    if len(data.shape) == 1:
+        data_copy = _logicle_inverse(data_copy, t, m, w, a)
+    else:
+        # run inverse logicle for each channel separately
+        if channel_indices is None:
+            channel_indices = range(data.shape[1])
+        for i in channel_indices:
+            tmp = _logicle_inverse(data_copy[:, i].T, t, m, w, a)
+            data_copy.T[i] = tmp
+
     return data_copy
 
 
@@ -127,8 +141,9 @@ def hyperlog(
         Bagwell CB. Hyperlog-a flexible log-like transform for negative, zero, and
         positive valued data. Cytometry A., 2005:64(1):34–42.
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter for the top of the linear scale (e.g. 262144)
     :param m: parameter for desired number of decades
     :param w: parameter for the approximate number of decades in the linear region
@@ -138,10 +153,16 @@ def hyperlog(
     """
     data_copy = data.copy()
 
-    # run hyperlog scale for each channel separately
-    for i in channel_indices:
-        tmp = _hyperlog(data_copy[:, i].T, t, m, w, a)
-        data_copy.T[i] = tmp
+    if len(data.shape) == 1:
+        data_copy = _hyperlog(data_copy, t, m, w, a)
+    else:
+        # run hyperlog scale for each channel separately
+        if channel_indices is None:
+            channel_indices = range(data.shape[1])
+        for i in channel_indices:
+            tmp = _hyperlog(data_copy[:, i].T, t, m, w, a)
+            data_copy.T[i] = tmp
+
     return data_copy
 
 
@@ -165,8 +186,9 @@ def hyperlog_inverse(
     Inverse of the Hyperlog transformation, implemented as defined in the
     GatingML 2.0 specification (see hyperlog() documentation for more details).
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter for the top of the linear scale (e.g. 262144)
     :param m: parameter for desired number of decades
     :param w: parameter for the approximate number of decades in the linear region
@@ -176,10 +198,15 @@ def hyperlog_inverse(
     """
     data_copy = data.copy()
 
-    # run hyperlog scale for each channel separately
-    for i in channel_indices:
-        tmp = _hyperlog_inverse(data_copy[:, i].T, t, m, w, a)
-        data_copy.T[i] = tmp
+    if len(data.shape) == 1:
+        data_copy = _hyperlog_inverse(data_copy, t, m, w, a)
+    else:
+        # run hyperlog scale for each channel separately
+        if channel_indices is None:
+            channel_indices = range(data.shape[1])
+        for i in channel_indices:
+            tmp = _hyperlog_inverse(data_copy[:, i].T, t, m, w, a)
+            data_copy.T[i] = tmp
     return data_copy
 
 
@@ -188,8 +215,9 @@ def asinh(data, channel_indices, t, m, a):
     An implementation of the parametrized inverse hyperbolic sine function
     as defined in the GatingML 2.0 specification.
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter specifying the top of the scale, (e.g. 262144)
     :param m: parameter for the number of decades
     :param a: parameter for the number of additional negative decades
@@ -202,9 +230,12 @@ def asinh(data, channel_indices, t, m, a):
 
     data_copy = data.copy()
 
-    tmp_data = (np.arcsinh(data_copy[:, channel_indices] * pre_scale) + transpose) / divisor
+    if len(data.shape) == 1 or channel_indices is None:
+        data_copy = (np.arcsinh(data_copy * pre_scale) + transpose) / divisor
+    else:
+        tmp_data = (np.arcsinh(data_copy[:, channel_indices] * pre_scale) + transpose) / divisor
 
-    data_copy[:, channel_indices] = tmp_data
+        data_copy[:, channel_indices] = tmp_data
 
     return data_copy
 
@@ -214,8 +245,9 @@ def asinh_inverse(data, channel_indices, t, m, a):
     Inverse of the parametrized inverse hyperbolic sine function
     as defined in the GatingML 2.0 specification.
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter specifying the top of the scale, (e.g. 262144)
     :param m: parameter for the number of decades
     :param a: parameter for the number of additional negative decades
@@ -227,7 +259,11 @@ def asinh_inverse(data, channel_indices, t, m, a):
     divisor = (m + a) * np.log(10)
 
     data_copy = data.copy()
-    data_copy[:, channel_indices] = (np.sinh((data_copy[:, channel_indices] * divisor) - transpose)) / pre_scale
+
+    if len(data.shape) == 1 or channel_indices is None:
+        data_copy = (np.sinh((data_copy * divisor) - transpose)) / pre_scale
+    else:
+        data_copy[:, channel_indices] = (np.sinh((data_copy[:, channel_indices] * divisor) - transpose)) / pre_scale
 
     return data_copy
 
@@ -239,15 +275,20 @@ def log(data, channel_indices, t, m):
 
     flog(x, T, M) = (1 / M) * log_10(x / T) + 1
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter for the top of the linear scale (e.g. 262144)
     :param m: parameter for desired number of decades
 
     :return: NumPy array of transformed events
     """
     data_copy = data.copy()
-    data_copy[:, channel_indices] = (1. / m) * np.log10(data_copy[:, channel_indices] / t) + 1.
+
+    if len(data.shape) == 1 or channel_indices is None:
+        data_copy = (1. / m) * np.log10(data_copy / t) + 1.
+    else:
+        data_copy[:, channel_indices] = (1. / m) * np.log10(data_copy[:, channel_indices] / t) + 1.
 
     return data_copy
 
@@ -256,14 +297,19 @@ def log_inverse(data, channel_indices, t, m):
     """
     Inverse of logarithmic transformation
 
-    :param data: NumPy array of FCS event data
-    :param channel_indices: channel indices to transform (other channels returned in place, untransformed)
+    :param data: NumPy array of FCS event data. If a 1-D array, channel_indices option is ignored
+    :param channel_indices: channel indices to transform (other channels returned in place, untransformed).
+        If None, then all events will be transformed.
     :param t: parameter for the top of the linear scale (e.g. 262144)
     :param m: parameter for desired number of decades
 
     :return: NumPy array of transformed events
     """
     data_copy = data.copy()
-    data_copy[:, channel_indices] = t * (10 ** ((data_copy[:, channel_indices] - 1) * m))
+
+    if len(data.shape) == 1 or channel_indices is None:
+        data_copy = t * (10 ** ((data_copy - 1) * m))
+    else:
+        data_copy[:, channel_indices] = t * (10 ** ((data_copy[:, channel_indices] - 1) * m))
 
     return data_copy
